@@ -3,7 +3,8 @@
 #'
 #' @param object   an object of class 'gllvm'.
 #' @param adjust  The type of adjustment used for  negative binomial and binomial distribution when computing residual correlation matrix. Options are 0 (no adjustment), 1 (the default adjustment) and 2 (alternative adjustment for NB distribution). See details.
-#' @param site.index A site index used used in the calculation of a GLLVM with quadratic response model, for which the residual correlations are calculated.
+#' @param x (optional) vector of covariate values to calculate the covariance for, when applicable.
+#' 
 #' @param ... not used
 #' 
 #' @details
@@ -22,7 +23,7 @@
 #'cr[1:5,1:5]
 #'\dontrun{
 #'# Load a dataset from the mvabund package
-#'data(antTraits)
+#'data(antTraits, package = "mvabund")
 #'y <- as.matrix(antTraits$abund)
 #'# Fit gllvm model
 #'fit <- gllvm(y = y, family = poisson())
@@ -40,9 +41,9 @@
 #'@method getResidualCor gllvm
 #'@export
 #'@export getResidualCor.gllvm
-getResidualCor.gllvm = function(object, adjust = 1, site.index = NULL, ...)
+getResidualCor.gllvm = function(object, adjust = 1, x = NULL, ...)
 {
-  ResCov <- getResidualCov.gllvm(object, adjust = adjust, site.index = site.index)$cov
+  ResCov <- getResidualCov.gllvm(object, adjust = adjust, x = x)$cov
   Res.sd <- 1 / sqrt(diag(ResCov))
   Res.Cor <- diag(Res.sd) %*% ResCov %*% diag(Res.sd)
   colnames(Res.Cor) <- colnames(object$y)
