@@ -209,7 +209,9 @@ summary.gllvm <- function(object, by = "all", digits = max(3L, getOption("digits
         for(i in 1:ncol(object$lv.X.design)){
           idx <- seq(i,ncol(object$lv.X.design)*(object$num.lv.c+object$num.RR),ncol(object$lv.X.design))
           b <- object$params$LvXcoef[i,]
-          zval[i] <- b%*%MASS::ginv(covB[idx,idx])%*%b
+          S <- MASS::ginv(covB[idx,idx])
+          if(any(diag(S)<0)){warning("Negative diagonal entries detected in the covariance matrix. This might give some odd results.\n")}
+          zval[i] <- b%*%S%*%b
           pvalue[i] <- 1-pchisq(zval[i],object$num.lv.c+object$num.RR)
         }
         coef.table.constrained <- cbind(pars, se, zval, pvalue)
@@ -282,7 +284,30 @@ summary.gllvm <- function(object, by = "all", digits = max(3L, getOption("digits
   }else if(!isFALSE(object$randomB)){
     coef.table.constrained <- NULL
     
-    REbcovs <- data.frame(Name = names(object$params$sigmaLvXcoef), Variance = format(round(object$params$sigmaLvXcoef^2, digits), nsmall = digits), Std.Dev = format(round(object$params$sigmaLvXcoef, digits), nsmall = digits))
+    REbcovs <- NULL
+    
+    if(object$randomB == "LV"){
+      sigma <- kronecker(object$params$sigmaLvXcoef, rep(1, ncol(object$lv.X.design)))
+    }else if(object$randomB == "P"){
+      sigma1 <- object$params$sigmaLvXcoef[1:ncol(object$lv.X.design)]
+      sigma2 <- object$params$sigmaLvXcoef[-c(1:ncol(object$lv.X.design))]
+      sigma <- kronecker(c(1, sigma2), sigma1)
+    }else{
+      sigma <- rep(object$params$sigmaLvXcoef, ncol(object$lv.X.design)*(object$num.lv.c+object$num.RR))
+    }
+    
+    REbcovs = data.frame(Name = rep(row.names(object$params$LvXcoef), object$num.lv.c+object$num.RR),
+                         Std.Dev = format(round(sigma, digits), nsmall = digits),
+                         Variance = format(round(sigma^2, digits), nsmall = digits),
+                         LV = rep(colnames(object$params$LvXcoef), each = ncol(object$lv.X.design)))
+    
+    REbcovs <- reshape(
+      REbcovs, 
+      timevar = "LV", 
+      idvar = "Name", 
+      direction = "wide"
+    )
+    
     if(!is.null(object$params$corsLvXcoef)){
       cors <- format(round(object$params$corsLvXcoef, digits), nsmall = digits)
       cors[upper.tri(cors, diag = TRUE)] <- ""
